@@ -60,7 +60,7 @@ class GetMediaShowItemView(BrowserView):
         if(self.isVideo(item) or item.portal_type == 'Image'):
             return item.absolute_url()
         
-        if item.portal_type == 'Link' and item.remoteUrl.find("youtube.com") > -1:
+        if item.portal_type == 'Link' and (item.remoteUrl.find("youtube.com") > -1 or item.remoteUrl.find("vimeo.com") > -1):
             return item.remoteUrl
         
         catalog = getToolByName(self.context, 'portal_catalog')
@@ -83,12 +83,14 @@ class GetMediaShowItemView(BrowserView):
         
     def getMediaType(self):
         """ Finds and returns the type of lead media
-        """
+        """ 
         item = self.context
         if(self.isVideo(item)):
             return "Video"
         elif item.portal_type == 'Link' and item.remoteUrl.find("youtube.com") > -1:
             return "Youtube"
+        elif item.portal_type == 'Link' and item.remoteUrl.find("vimeo.com") > -1:
+            return "Vimeo"
         else:
             return "Image"
     
@@ -125,9 +127,10 @@ class MediaShowListingView(BrowserView):
         resultArray = []
         
         #Python to JSON encoding
-        for res in results: 
-            resultArray.append({"url": res.getURL(), "UID": res["UID"]})
-            
+        for res in results:
+            if(self.getMediaURL(res.getObject()) != ""):
+                resultArray.append({"url": res.getURL(), "UID": res["UID"]})
+
         jsonStr = json.dumps(resultArray)
             
         #Manual encoding 
@@ -153,7 +156,7 @@ class MediaShowListingView(BrowserView):
         if(self.isVideo(item)):
             return item.absolute_url()
             
-        if item.portal_type == 'Link' and item.remoteUrl.find("youtube.com") > -1:
+        if item.portal_type == 'Link' and (item.remoteUrl.find("youtube.com") > -1 or item.remoteUrl.find("vimeo.com") > -1):
             return item.remoteUrl
         
         if item.portal_type == 'Image':
